summaryrefslogtreecommitdiff
path: root/misc.c
diff options
context:
space:
mode:
authorBoris Kolpackov <boris@kolpackov.net>2005-02-27 22:24:30 +0000
committerBoris Kolpackov <boris@kolpackov.net>2005-02-27 22:24:30 +0000
commit93bd1bd93c1033352e5059ed721a0cc769449639 (patch)
treeb3d69f597a1e32659e227388346363cfdbdec465 /misc.c
parent659fc6b55e28740c74d66dbe3bda765d1004a12e (diff)
downloadgunmake-93bd1bd93c1033352e5059ed721a0cc769449639.tar.gz
Implementation of the .DEFAULT_TARGET special variable.
Diffstat (limited to 'misc.c')
-rw-r--r--misc.c18
1 files changed, 9 insertions, 9 deletions
diff --git a/misc.c b/misc.c
index 4f1f864..53c1923 100644
--- a/misc.c
+++ b/misc.c
@@ -525,22 +525,22 @@ copy_dep_chain (struct dep *d)
return firstnew;
}
-/* Free a chain of `struct dep'. Each dep->name is freed
- as well. */
+/* Free a chain of `struct nameseq'. Each nameseq->name is freed
+ as well. Can be used on `struct dep' chains.*/
void
-free_dep_chain (struct dep *d)
+free_ns_chain (struct nameseq *n)
{
- register struct dep *tmp;
+ register struct nameseq *tmp;
- while (d != 0)
+ while (n != 0)
{
- if (d->name != 0)
- free (d->name);
+ if (n->name != 0)
+ free (n->name);
- tmp = d;
+ tmp = n;
- d = d->next;
+ n = n->next;
free (tmp);
}